"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

import pydantic
from typing_extensions import Annotated, TypedDict

from friendli_core.types import BaseModel


class FileGetDownloadURLResponseTypedDict(TypedDict):
    r"""Get download URL response."""

    download_url: str
    r"""Download URL of the file."""
    file_id: str
    r"""ID of the file."""
    s3_uri: str
    r"""S3 URI of the file."""


class FileGetDownloadURLResponse(BaseModel):
    r"""Get download URL response."""

    download_url: Annotated[str, pydantic.Field(alias="downloadUrl")]
    r"""Download URL of the file."""

    file_id: Annotated[str, pydantic.Field(alias="fileId")]
    r"""ID of the file."""

    s3_uri: Annotated[str, pydantic.Field(alias="s3Uri")]
    r"""S3 URI of the file."""
