"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

import pydantic
from typing_extensions import Annotated, TypedDict

from friendli_core.types import BaseModel


class SplitInfoTypedDict(TypedDict):
    r"""Split info."""

    created_at: int
    r"""Unix timestamp (in seconds) of when the split was created."""
    id: str
    r"""ID of the split."""
    name: str
    r"""Name of the split."""
    updated_at: int
    r"""Unix timestamp (in seconds) of when the split was last modified."""


class SplitInfo(BaseModel):
    r"""Split info."""

    created_at: Annotated[int, pydantic.Field(alias="createdAt")]
    r"""Unix timestamp (in seconds) of when the split was created."""

    id: str
    r"""ID of the split."""

    name: str
    r"""Name of the split."""

    updated_at: Annotated[int, pydantic.Field(alias="updatedAt")]
    r"""Unix timestamp (in seconds) of when the split was last modified."""
