"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from importlib import import_module
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from .acceleratorrequirement import (
        AcceleratorRequirement,
        AcceleratorRequirementTypedDict,
    )
    from .accountfilestatus import AccountFileStatus
    from .add_samplesop import AddSamplesRequest, AddSamplesRequestTypedDict
    from .addsamplesresponse import AddSamplesResponse, AddSamplesResponseTypedDict
    from .assistantmessage import AssistantMessage, AssistantMessageTypedDict
    from .assistantmessagetoolcall import (
        AssistantMessageToolCall,
        AssistantMessageToolCallTypedDict,
    )
    from .assistantmessagetoolcallfunction import (
        AssistantMessageToolCallFunction,
        AssistantMessageToolCallFunctionTypedDict,
    )
    from .audiocontent import AudioContent, AudioContentTypedDict
    from .audiodata import AudioData, AudioDataTypedDict
    from .autoscalingpolicy import AutoscalingPolicy, AutoscalingPolicyTypedDict
    from .b64imageitem import (
        B64ImageItem,
        B64ImageItemResponseFormat,
        B64ImageItemTypedDict,
    )
    from .body_upload_raw_samples import (
        BodyUploadRawSamples,
        BodyUploadRawSamplesTypedDict,
        FileModel,
        FileModelTypedDict,
    )
    from .chatchoice import ChatChoice, ChatChoiceTypedDict, FinishReason
    from .chatchoicemessage import ChatChoiceMessage, ChatChoiceMessageTypedDict
    from .chatcompletebodytoolchoice import (
        ChatCompleteBodyToolChoice,
        ChatCompleteBodyToolChoiceTypedDict,
    )
    from .chatcompletebodytoolchoicefunction import (
        ChatCompleteBodyToolChoiceFunction,
        ChatCompleteBodyToolChoiceFunctionTypedDict,
    )
    from .chatlogprobs import ChatLogprobs, ChatLogprobsTypedDict
    from .chatlogprobscontent import ChatLogprobsContent, ChatLogprobsContentTypedDict
    from .chatlogprobscontenttoplogprob import (
        ChatLogprobsContentTopLogprob,
        ChatLogprobsContentTopLogprobTypedDict,
    )
    from .chatusage import ChatUsage, ChatUsageTypedDict
    from .complete_uploadop import CompleteUploadRequest, CompleteUploadRequestTypedDict
    from .completionsbodywithprompt import (
        CompletionsBodyWithPrompt,
        CompletionsBodyWithPromptSeed,
        CompletionsBodyWithPromptSeedTypedDict,
        CompletionsBodyWithPromptTypedDict,
        Prompt,
        PromptTypedDict,
    )
    from .completionsbodywithtokens import (
        CompletionsBodyWithTokens,
        CompletionsBodyWithTokensSeed,
        CompletionsBodyWithTokensSeedTypedDict,
        CompletionsBodyWithTokensTypedDict,
    )
    from .completionschoice import (
        CompletionsChoice,
        CompletionsChoiceFinishReason,
        CompletionsChoiceTypedDict,
    )
    from .completionsdedicatedbodywithprompt import (
        CompletionsDedicatedBodyWithPrompt,
        CompletionsDedicatedBodyWithPromptPrompt,
        CompletionsDedicatedBodyWithPromptPromptTypedDict,
        CompletionsDedicatedBodyWithPromptSeed,
        CompletionsDedicatedBodyWithPromptSeedTypedDict,
        CompletionsDedicatedBodyWithPromptTypedDict,
    )
    from .completionsdedicatedbodywithtokens import (
        CompletionsDedicatedBodyWithTokens,
        CompletionsDedicatedBodyWithTokensSeed,
        CompletionsDedicatedBodyWithTokensSeedTypedDict,
        CompletionsDedicatedBodyWithTokensTypedDict,
    )
    from .completionslogprobs import CompletionsLogprobs, CompletionsLogprobsTypedDict
    from .completionsserverlessbodywithprompt import (
        CompletionsServerlessBodyWithPrompt,
        CompletionsServerlessBodyWithPromptPrompt,
        CompletionsServerlessBodyWithPromptPromptTypedDict,
        CompletionsServerlessBodyWithPromptSeed,
        CompletionsServerlessBodyWithPromptSeedTypedDict,
        CompletionsServerlessBodyWithPromptTypedDict,
    )
    from .completionsserverlessbodywithtokens import (
        CompletionsServerlessBodyWithTokens,
        CompletionsServerlessBodyWithTokensSeed,
        CompletionsServerlessBodyWithTokensSeedTypedDict,
        CompletionsServerlessBodyWithTokensTypedDict,
    )
    from .completionsstreambodywithprompt import (
        CompletionsStreamBodyWithPrompt,
        CompletionsStreamBodyWithPromptPrompt,
        CompletionsStreamBodyWithPromptPromptTypedDict,
        CompletionsStreamBodyWithPromptSeed,
        CompletionsStreamBodyWithPromptSeedTypedDict,
        CompletionsStreamBodyWithPromptTypedDict,
    )
    from .completionsstreambodywithtokens import (
        CompletionsStreamBodyWithTokens,
        CompletionsStreamBodyWithTokensSeed,
        CompletionsStreamBodyWithTokensSeedTypedDict,
        CompletionsStreamBodyWithTokensTypedDict,
    )
    from .completionsstreamdedicatedbodywithprompt import (
        CompletionsStreamDedicatedBodyWithPrompt,
        CompletionsStreamDedicatedBodyWithPromptPrompt,
        CompletionsStreamDedicatedBodyWithPromptPromptTypedDict,
        CompletionsStreamDedicatedBodyWithPromptSeed,
        CompletionsStreamDedicatedBodyWithPromptSeedTypedDict,
        CompletionsStreamDedicatedBodyWithPromptTypedDict,
    )
    from .completionsstreamdedicatedbodywithtokens import (
        CompletionsStreamDedicatedBodyWithTokens,
        CompletionsStreamDedicatedBodyWithTokensSeed,
        CompletionsStreamDedicatedBodyWithTokensSeedTypedDict,
        CompletionsStreamDedicatedBodyWithTokensTypedDict,
    )
    from .completionsstreamserverlessbodywithprompt import (
        CompletionsStreamServerlessBodyWithPrompt,
        CompletionsStreamServerlessBodyWithPromptPrompt,
        CompletionsStreamServerlessBodyWithPromptPromptTypedDict,
        CompletionsStreamServerlessBodyWithPromptSeed,
        CompletionsStreamServerlessBodyWithPromptSeedTypedDict,
        CompletionsStreamServerlessBodyWithPromptTypedDict,
    )
    from .completionsstreamserverlessbodywithtokens import (
        CompletionsStreamServerlessBodyWithTokens,
        CompletionsStreamServerlessBodyWithTokensSeed,
        CompletionsStreamServerlessBodyWithTokensSeedTypedDict,
        CompletionsStreamServerlessBodyWithTokensTypedDict,
    )
    from .containerchatcompleteop import CONTAINER_CHAT_COMPLETE_OP_SERVERS
    from .containerchatcompletesuccess import (
        ContainerChatCompleteSuccess,
        ContainerChatCompleteSuccessTypedDict,
    )
    from .containerchatcompletionbody import (
        ContainerChatCompletionBody,
        ContainerChatCompletionBodyTypedDict,
        Seed,
        SeedTypedDict,
        ToolChoice,
        ToolChoiceTypedDict,
    )
    from .containerchatcompletionstreambody import (
        ContainerChatCompletionStreamBody,
        ContainerChatCompletionStreamBodySeed,
        ContainerChatCompletionStreamBodySeedTypedDict,
        ContainerChatCompletionStreamBodyToolChoice,
        ContainerChatCompletionStreamBodyToolChoiceTypedDict,
        ContainerChatCompletionStreamBodyTypedDict,
    )
    from .containerchatcompletionstreamsuccess import (
        ContainerChatCompletionStreamSuccess,
        ContainerChatCompletionStreamSuccessTypedDict,
    )
    from .containerchatstreamop import CONTAINER_CHAT_STREAM_OP_SERVERS
    from .containercompletionsbody import (
        ContainerCompletionsBody,
        ContainerCompletionsBodyTypedDict,
    )
    from .containercompletionscompleteop import (
        CONTAINER_COMPLETIONS_COMPLETE_OP_SERVERS,
    )
    from .containercompletionsstreambody import (
        ContainerCompletionsStreamBody,
        ContainerCompletionsStreamBodyTypedDict,
    )
    from .containercompletionsstreamop import CONTAINER_COMPLETIONS_STREAM_OP_SERVERS
    from .containercompletionsstreamsuccess import (
        ContainerCompletionsStreamSuccess,
        ContainerCompletionsStreamSuccessTypedDict,
    )
    from .containercompletionssuccess import (
        ContainerCompletionsSuccess,
        ContainerCompletionsSuccessTypedDict,
    )
    from .containerdetokenizationbody import (
        ContainerDetokenizationBody,
        ContainerDetokenizationBodyTypedDict,
    )
    from .containerdetokenizationop import CONTAINER_DETOKENIZATION_OP_SERVERS
    from .containerdetokenizationsuccess import (
        ContainerDetokenizationSuccess,
        ContainerDetokenizationSuccessTypedDict,
    )
    from .containerimagegeneratesuccess import (
        ContainerImageGenerateSuccess,
        ContainerImageGenerateSuccessTypedDict,
    )
    from .containerimagegenerationbody import (
        ContainerImageGenerationBody,
        ContainerImageGenerationBodyResponseFormat,
        ContainerImageGenerationBodyTypedDict,
    )
    from .containerimagesgenerateop import CONTAINER_IMAGES_GENERATE_OP_SERVERS
    from .containertokenizationbody import (
        ContainerTokenizationBody,
        ContainerTokenizationBodyTypedDict,
    )
    from .containertokenizationop import CONTAINER_TOKENIZATION_OP_SERVERS
    from .containertokenizationsuccess import (
        ContainerTokenizationSuccess,
        ContainerTokenizationSuccessTypedDict,
    )
    from .create_datasetop import CreateDatasetRequest1, CreateDatasetRequest1TypedDict
    from .create_splitop import CreateSplitRequest, CreateSplitRequestTypedDict
    from .create_versionop import CreateVersionRequest, CreateVersionRequestTypedDict
    from .createdatasetrequest import (
        CreateDatasetRequest,
        CreateDatasetRequestTypedDict,
    )
    from .datasetinfo import DatasetInfo, DatasetInfoTypedDict
    from .dedicatedchatcompleteop import (
        DedicatedChatCompleteRequest,
        DedicatedChatCompleteRequestTypedDict,
    )
    from .dedicatedchatcompletionbody import (
        DedicatedChatCompletionBody,
        DedicatedChatCompletionBodySeed,
        DedicatedChatCompletionBodySeedTypedDict,
        DedicatedChatCompletionBodyToolChoice,
        DedicatedChatCompletionBodyToolChoiceTypedDict,
        DedicatedChatCompletionBodyTypedDict,
    )
    from .dedicatedchatcompletionstreambody import (
        DedicatedChatCompletionStreamBody,
        DedicatedChatCompletionStreamBodySeed,
        DedicatedChatCompletionStreamBodySeedTypedDict,
        DedicatedChatCompletionStreamBodyToolChoice,
        DedicatedChatCompletionStreamBodyToolChoiceTypedDict,
        DedicatedChatCompletionStreamBodyTypedDict,
    )
    from .dedicatedchatstreamop import (
        DedicatedChatStreamRequest,
        DedicatedChatStreamRequestTypedDict,
    )
    from .dedicatedcompletionsbody import (
        DedicatedCompletionsBody,
        DedicatedCompletionsBodyTypedDict,
    )
    from .dedicatedcompletionscompleteop import (
        DedicatedCompletionsCompleteRequest,
        DedicatedCompletionsCompleteRequestTypedDict,
    )
    from .dedicatedcompletionsstreambody import (
        DedicatedCompletionsStreamBody,
        DedicatedCompletionsStreamBodyTypedDict,
    )
    from .dedicatedcompletionsstreamop import (
        DedicatedCompletionsStreamRequest,
        DedicatedCompletionsStreamRequestTypedDict,
    )
    from .dedicatedcreateendpointbetaop import (
        DedicatedCreateEndpointBetaRequest,
        DedicatedCreateEndpointBetaRequestTypedDict,
    )
    from .dedicatedcreateendpointop import (
        DedicatedCreateEndpointRequest,
        DedicatedCreateEndpointRequestTypedDict,
    )
    from .dedicateddatasetmodality import (
        DedicatedDatasetModality,
        DedicatedDatasetModalityTypedDict,
    )
    from .dedicateddatasetmodalitytype import DedicatedDatasetModalityType
    from .dedicateddeleteendpointop import (
        DedicatedDeleteEndpointRequest,
        DedicatedDeleteEndpointRequestTypedDict,
    )
    from .dedicateddetokenizationbody import (
        DedicatedDetokenizationBody,
        DedicatedDetokenizationBodyTypedDict,
    )
    from .dedicateddetokenizationop import (
        DedicatedDetokenizationRequest,
        DedicatedDetokenizationRequestTypedDict,
    )
    from .dedicateddetokenizationsuccess import (
        DedicatedDetokenizationSuccess,
        DedicatedDetokenizationSuccessTypedDict,
    )
    from .dedicatedendpointcreatebody import (
        DedicatedEndpointCreateBody,
        DedicatedEndpointCreateBodyTypedDict,
    )
    from .dedicatedendpointlistresponse import (
        DedicatedEndpointListResponse,
        DedicatedEndpointListResponseTypedDict,
    )
    from .dedicatedendpointspec import (
        DedicatedEndpointSpec,
        DedicatedEndpointSpecTypedDict,
    )
    from .dedicatedendpointspecbeta import (
        DedicatedEndpointSpecBeta,
        DedicatedEndpointSpecBetaTypedDict,
    )
    from .dedicatedendpointstatus import (
        DedicatedEndpointStatus,
        DedicatedEndpointStatusTypedDict,
        Phase,
    )
    from .dedicatedendpointupdatebody import (
        DedicatedEndpointUpdateBody,
        DedicatedEndpointUpdateBodyTypedDict,
    )
    from .dedicatedendpointversionhistoryresponse import (
        DedicatedEndpointVersionHistoryResponse,
        DedicatedEndpointVersionHistoryResponseTypedDict,
    )
    from .dedicatedendpointwandbartifactcreatebody import (
        DedicatedEndpointWandbArtifactCreateBody,
        DedicatedEndpointWandbArtifactCreateBodyTypedDict,
    )
    from .dedicatedendpointwandbartifactcreateop import (
        DedicatedEndpointWandbArtifactCreateRequest,
        DedicatedEndpointWandbArtifactCreateRequestTypedDict,
    )
    from .dedicatedendpointwandbartifactcreateresponse import (
        DedicatedEndpointWandbArtifactCreateResponse,
        DedicatedEndpointWandbArtifactCreateResponseTypedDict,
    )
    from .dedicatedgetendpointbetaop import (
        DedicatedGetEndpointBetaRequest,
        DedicatedGetEndpointBetaRequestTypedDict,
    )
    from .dedicatedgetendpointop import (
        DedicatedGetEndpointRequest,
        DedicatedGetEndpointRequestTypedDict,
    )
    from .dedicatedgetendpointstatusbetaop import (
        DedicatedGetEndpointStatusBetaRequest,
        DedicatedGetEndpointStatusBetaRequestTypedDict,
    )
    from .dedicatedgetendpointstatusop import (
        DedicatedGetEndpointStatusRequest,
        DedicatedGetEndpointStatusRequestTypedDict,
    )
    from .dedicatedgetendpointversionhistoryop import (
        DedicatedGetEndpointVersionHistoryRequest,
        DedicatedGetEndpointVersionHistoryRequestTypedDict,
    )
    from .dedicatedimagegeneratesuccess import (
        Data,
        DataTypedDict,
        DedicatedImageGenerateSuccess,
        DedicatedImageGenerateSuccessTypedDict,
    )
    from .dedicatedimagegenerationbody import (
        DedicatedImageGenerationBody,
        DedicatedImageGenerationBodyResponseFormat,
        DedicatedImageGenerationBodyTypedDict,
    )
    from .dedicatedimagesgenerateop import (
        DedicatedImagesGenerateRequest,
        DedicatedImagesGenerateRequestTypedDict,
    )
    from .dedicatedlistendpointsbetaop import (
        DedicatedListEndpointsBetaRequest,
        DedicatedListEndpointsBetaRequestTypedDict,
    )
    from .dedicatedlistendpointsop import (
        DedicatedListEndpointsRequest,
        DedicatedListEndpointsRequestTypedDict,
    )
    from .dedicatedrestartendpointbetaop import (
        DedicatedRestartEndpointBetaRequest,
        DedicatedRestartEndpointBetaRequestTypedDict,
    )
    from .dedicatedrestartendpointop import (
        DedicatedRestartEndpointRequest,
        DedicatedRestartEndpointRequestTypedDict,
    )
    from .dedicatedsleependpointop import (
        DedicatedSleepEndpointRequest,
        DedicatedSleepEndpointRequestTypedDict,
    )
    from .dedicatedterminateendpointbetaop import (
        DedicatedTerminateEndpointBetaRequest,
        DedicatedTerminateEndpointBetaRequestTypedDict,
    )
    from .dedicatedterminateendpointop import (
        DedicatedTerminateEndpointRequest,
        DedicatedTerminateEndpointRequestTypedDict,
    )
    from .dedicatedtokenizationbody import (
        DedicatedTokenizationBody,
        DedicatedTokenizationBodyTypedDict,
    )
    from .dedicatedtokenizationop import (
        DedicatedTokenizationRequest,
        DedicatedTokenizationRequestTypedDict,
    )
    from .dedicatedtokenizationsuccess import (
        DedicatedTokenizationSuccess,
        DedicatedTokenizationSuccessTypedDict,
    )
    from .dedicatedupdateendpointbetaop import (
        DedicatedUpdateEndpointBetaRequest,
        DedicatedUpdateEndpointBetaRequestTypedDict,
    )
    from .dedicatedupdateendpointop import (
        DedicatedUpdateEndpointRequest,
        DedicatedUpdateEndpointRequestTypedDict,
    )
    from .dedicatedwakeendpointop import (
        DedicatedWakeEndpointRequest,
        DedicatedWakeEndpointRequestTypedDict,
    )
    from .delete_datasetop import DeleteDatasetRequest, DeleteDatasetRequestTypedDict
    from .delete_samplesop import (
        DeleteSamplesRequest,
        DeleteSamplesRequestTypedDict,
        RequestBody,
        RequestBodyTypedDict,
    )
    from .delete_splitop import DeleteSplitRequest, DeleteSplitRequestTypedDict
    from .delete_versionop import DeleteVersionRequest, DeleteVersionRequestTypedDict
    from .deletesamplesresponse import (
        DeleteSamplesResponse,
        DeleteSamplesResponseTypedDict,
    )
    from .endpointadvancedconfig import (
        EndpointAdvancedConfig,
        EndpointAdvancedConfigTypedDict,
    )
    from .endpointsimplescaleconfig import (
        EndpointSimplescaleConfig,
        EndpointSimplescaleConfigTypedDict,
    )
    from .filebuiltintool import FileBuiltInTool, FileBuiltInToolTypedDict
    from .filegetdownloadurlresponse import (
        FileGetDownloadURLResponse,
        FileGetDownloadURLResponseTypedDict,
    )
    from .fileinfo import FileInfo, FileInfoTypedDict
    from .fileinituploadrequest import (
        FileInitUploadRequest,
        FileInitUploadRequestTypedDict,
    )
    from .fileinituploadresponse import (
        FileInitUploadResponse,
        FileInitUploadResponseTypedDict,
    )
    from .function import Function, FunctionTypedDict
    from .functionality import Functionality, FunctionalityTypedDict
    from .functionresult import FunctionResult, FunctionResultTypedDict
    from .get_datasetop import GetDatasetRequest, GetDatasetRequestTypedDict
    from .get_download_urlop import (
        GetDownloadURLRequest,
        GetDownloadURLRequestTypedDict,
    )
    from .get_infoop import GetInfoRequest, GetInfoRequestTypedDict
    from .get_splitop import GetSplitRequest, GetSplitRequestTypedDict
    from .get_versionop import GetVersionRequest, GetVersionRequestTypedDict
    from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
    from .imagecontent import ImageContent, ImageContentTypedDict
    from .imagedata import ImageData, ImageDataTypedDict
    from .inferencedeploymenterrorcode import InferenceDeploymentErrorCode
    from .inferencedeploymentstatus import InferenceDeploymentStatus
    from .init_uploadop import InitUploadRequest, InitUploadRequestTypedDict
    from .knowledgeretrievedchunk import (
        KnowledgeRetrievedChunk,
        KnowledgeRetrievedChunkTypedDict,
    )
    from .list_datasetsop import (
        Direction,
        ListDatasetsRequest,
        ListDatasetsRequestTypedDict,
    )
    from .list_samplesop import (
        ListSamplesQueryParamDirection,
        ListSamplesRequest,
        ListSamplesRequestTypedDict,
    )
    from .list_splitsop import (
        ListSplitsRequest,
        ListSplitsRequestTypedDict,
        QueryParamDirection,
    )
    from .list_versionsop import ListVersionsRequest, ListVersionsRequestTypedDict
    from .listdatasetsresponse import (
        ListDatasetsResponse,
        ListDatasetsResponseTypedDict,
    )
    from .listsamplesresponse import ListSamplesResponse, ListSamplesResponseTypedDict
    from .listsplitsresponse import ListSplitsResponse, ListSplitsResponseTypedDict
    from .listversionsresponse import (
        ListVersionsResponse,
        ListVersionsResponseTypedDict,
    )
    from .message import Message, MessageTypedDict
    from .modelcatalogresponseitem import (
        ModelCatalogResponseItem,
        ModelCatalogResponseItemTypedDict,
    )
    from .otherbuiltintool import OtherBuiltInTool, OtherBuiltInToolTypedDict, Type
    from .pricingmodel import PricingModel, PricingModelTypedDict
    from .responseformat import ResponseFormat, ResponseFormatTypedDict
    from .responseformatjsonobject import (
        ResponseFormatJSONObject,
        ResponseFormatJSONObjectTypedDict,
    )
    from .responseformatjsonschema import (
        ResponseFormatJSONSchema,
        ResponseFormatJSONSchemaTypedDict,
    )
    from .responseformatjsonschemaschema import (
        ResponseFormatJSONSchemaSchema,
        ResponseFormatJSONSchemaSchemaTypedDict,
    )
    from .responseformatregex import ResponseFormatRegex, ResponseFormatRegexTypedDict
    from .responseformattext import ResponseFormatText, ResponseFormatTextTypedDict
    from .sdkerror import SDKError
    from .security import Security, SecurityTypedDict
    from .serverlesschatcompleteop import (
        ServerlessChatCompleteRequest,
        ServerlessChatCompleteRequestTypedDict,
    )
    from .serverlesschatcompletionbody import (
        ServerlessChatCompletionBody,
        ServerlessChatCompletionBodySeed,
        ServerlessChatCompletionBodySeedTypedDict,
        ServerlessChatCompletionBodyToolChoice,
        ServerlessChatCompletionBodyToolChoiceTypedDict,
        ServerlessChatCompletionBodyTypedDict,
    )
    from .serverlesschatcompletionstreambody import (
        ServerlessChatCompletionStreamBody,
        ServerlessChatCompletionStreamBodySeed,
        ServerlessChatCompletionStreamBodySeedTypedDict,
        ServerlessChatCompletionStreamBodyToolChoice,
        ServerlessChatCompletionStreamBodyToolChoiceTypedDict,
        ServerlessChatCompletionStreamBodyTypedDict,
    )
    from .serverlesschatstreamop import (
        ServerlessChatStreamRequest,
        ServerlessChatStreamRequestTypedDict,
    )
    from .serverlesscompletionsbody import (
        ServerlessCompletionsBody,
        ServerlessCompletionsBodyTypedDict,
    )
    from .serverlesscompletionscompleteop import (
        ServerlessCompletionsCompleteRequest,
        ServerlessCompletionsCompleteRequestTypedDict,
    )
    from .serverlesscompletionsstreambody import (
        ServerlessCompletionsStreamBody,
        ServerlessCompletionsStreamBodyTypedDict,
    )
    from .serverlesscompletionsstreamop import (
        ServerlessCompletionsStreamRequest,
        ServerlessCompletionsStreamRequestTypedDict,
    )
    from .serverlessdetokenizationbody import (
        ServerlessDetokenizationBody,
        ServerlessDetokenizationBodyTypedDict,
    )
    from .serverlessdetokenizationop import (
        ServerlessDetokenizationRequest,
        ServerlessDetokenizationRequestTypedDict,
    )
    from .serverlessdetokenizationsuccess import (
        ServerlessDetokenizationSuccess,
        ServerlessDetokenizationSuccessTypedDict,
    )
    from .serverlessknowledgeretrievalbody import (
        ServerlessKnowledgeRetrievalBody,
        ServerlessKnowledgeRetrievalBodyTypedDict,
    )
    from .serverlessknowledgeretrievalsuccess import (
        ServerlessKnowledgeRetrievalSuccess,
        ServerlessKnowledgeRetrievalSuccessTypedDict,
    )
    from .serverlessknowledgeretrieveop import (
        ServerlessKnowledgeRetrieveRequest,
        ServerlessKnowledgeRetrieveRequestTypedDict,
    )
    from .serverlessmodellistsuccess import (
        ServerlessModelListSuccess,
        ServerlessModelListSuccessTypedDict,
    )
    from .serverlesstokenizationbody import (
        ServerlessTokenizationBody,
        ServerlessTokenizationBodyTypedDict,
    )
    from .serverlesstokenizationop import (
        ServerlessTokenizationRequest,
        ServerlessTokenizationRequestTypedDict,
    )
    from .serverlesstokenizationsuccess import (
        ServerlessTokenizationSuccess,
        ServerlessTokenizationSuccessTypedDict,
    )
    from .serverlesstoolassistedchatcompleteop import (
        ServerlessToolAssistedChatCompleteRequest,
        ServerlessToolAssistedChatCompleteRequestTypedDict,
    )
    from .serverlesstoolassistedchatcompletionbody import (
        ServerlessToolAssistedChatCompletionBody,
        ServerlessToolAssistedChatCompletionBodySeed,
        ServerlessToolAssistedChatCompletionBodySeedTypedDict,
        ServerlessToolAssistedChatCompletionBodyToolChoice,
        ServerlessToolAssistedChatCompletionBodyToolChoiceTypedDict,
        ServerlessToolAssistedChatCompletionBodyTypedDict,
    )
    from .serverlesstoolassistedchatcompletionstreambody import (
        ServerlessToolAssistedChatCompletionStreamBody,
        ServerlessToolAssistedChatCompletionStreamBodySeed,
        ServerlessToolAssistedChatCompletionStreamBodySeedTypedDict,
        ServerlessToolAssistedChatCompletionStreamBodyToolChoice,
        ServerlessToolAssistedChatCompletionStreamBodyToolChoiceTypedDict,
        ServerlessToolAssistedChatCompletionStreamBodyTypedDict,
    )
    from .serverlesstoolassistedchatcompletionstreamsuccess import (
        ServerlessToolAssistedChatCompletionStreamSuccess,
        ServerlessToolAssistedChatCompletionStreamSuccessTypedDict,
    )
    from .serverlesstoolassistedchatstreamop import (
        ServerlessToolAssistedChatStreamRequest,
        ServerlessToolAssistedChatStreamRequestTypedDict,
    )
    from .splitinfo import SplitInfo, SplitInfoTypedDict
    from .streamedchatchoice import (
        StreamedChatChoice,
        StreamedChatChoiceFinishReason,
        StreamedChatChoiceTypedDict,
    )
    from .streamedchatchoicedelta import (
        StreamedChatChoiceDelta,
        StreamedChatChoiceDeltaTypedDict,
    )
    from .streamedchatdata import StreamedChatData, StreamedChatDataTypedDict
    from .streamedcompletiondata import (
        StreamedCompletionData,
        StreamedCompletionDataTypedDict,
    )
    from .streamedcompletionschoice import (
        StreamedCompletionsChoice,
        StreamedCompletionsChoiceFinishReason,
        StreamedCompletionsChoiceTypedDict,
    )
    from .streamedfunctionresult import (
        StreamedFunctionResult,
        StreamedFunctionResultTypedDict,
    )
    from .streamedtoolassistedchattoken import (
        StreamedToolAssistedChatToken,
        StreamedToolAssistedChatTokenTypedDict,
    )
    from .streamedtoolassistedchattoolstatus import (
        StreamedToolAssistedChatToolStatus,
        StreamedToolAssistedChatToolStatusTypedDict,
    )
    from .streamedtoolcallresult import (
        StreamedToolCallResult,
        StreamedToolCallResultTypedDict,
    )
    from .streamoptions import StreamOptions, StreamOptionsTypedDict
    from .systemmessage import SystemMessage, SystemMessageTypedDict
    from .textcontent import TextContent, TextContentTypedDict
    from .tokensequence import TokenSequence, TokenSequenceTypedDict
    from .tool import Tool, ToolTypedDict
    from .toolassistedchattool import (
        ToolAssistedChatTool,
        ToolAssistedChatToolTypedDict,
    )
    from .toolcallresult import ToolCallResult, ToolCallResultTypedDict
    from .toolmessage import ToolMessage, ToolMessageTypedDict
    from .toolstatusdata import Name, Status, ToolStatusData, ToolStatusDataTypedDict
    from .toolstatuserror import ToolStatusError, ToolStatusErrorTypedDict
    from .toolstatusfile import ToolStatusFile, ToolStatusFileTypedDict
    from .toolstatusparameter import ToolStatusParameter, ToolStatusParameterTypedDict
    from .upload_raw_samplesop import (
        UploadRawSamplesRequest,
        UploadRawSamplesRequestTypedDict,
    )
    from .urlimageitem import (
        URLImageItem,
        URLImageItemResponseFormat,
        URLImageItemTypedDict,
    )
    from .usage import Usage, UsageTypedDict
    from .usermessage import (
        Content,
        ContentTypedDict,
        UserMessage,
        UserMessageTypedDict,
    )
    from .usermessagecontentmultimodal import (
        UserMessageContentMultiModal,
        UserMessageContentMultiModalTypedDict,
    )
    from .validationerror import (
        Loc,
        LocTypedDict,
        ValidationError,
        ValidationErrorTypedDict,
    )
    from .versioninfo import VersionInfo, VersionInfoTypedDict
    from .videocontent import VideoContent, VideoContentTypedDict
    from .videodata import VideoData, VideoDataTypedDict

__all__ = [
    "AcceleratorRequirement",
    "AcceleratorRequirementTypedDict",
    "AccountFileStatus",
    "AddSamplesRequest",
    "AddSamplesRequestTypedDict",
    "AddSamplesResponse",
    "AddSamplesResponseTypedDict",
    "AssistantMessage",
    "AssistantMessageToolCall",
    "AssistantMessageToolCallFunction",
    "AssistantMessageToolCallFunctionTypedDict",
    "AssistantMessageToolCallTypedDict",
    "AssistantMessageTypedDict",
    "AudioContent",
    "AudioContentTypedDict",
    "AudioData",
    "AudioDataTypedDict",
    "AutoscalingPolicy",
    "AutoscalingPolicyTypedDict",
    "B64ImageItem",
    "B64ImageItemResponseFormat",
    "B64ImageItemTypedDict",
    "BodyUploadRawSamples",
    "BodyUploadRawSamplesTypedDict",
    "CONTAINER_CHAT_COMPLETE_OP_SERVERS",
    "CONTAINER_CHAT_STREAM_OP_SERVERS",
    "CONTAINER_COMPLETIONS_COMPLETE_OP_SERVERS",
    "CONTAINER_COMPLETIONS_STREAM_OP_SERVERS",
    "CONTAINER_DETOKENIZATION_OP_SERVERS",
    "CONTAINER_IMAGES_GENERATE_OP_SERVERS",
    "CONTAINER_TOKENIZATION_OP_SERVERS",
    "ChatChoice",
    "ChatChoiceMessage",
    "ChatChoiceMessageTypedDict",
    "ChatChoiceTypedDict",
    "ChatCompleteBodyToolChoice",
    "ChatCompleteBodyToolChoiceFunction",
    "ChatCompleteBodyToolChoiceFunctionTypedDict",
    "ChatCompleteBodyToolChoiceTypedDict",
    "ChatLogprobs",
    "ChatLogprobsContent",
    "ChatLogprobsContentTopLogprob",
    "ChatLogprobsContentTopLogprobTypedDict",
    "ChatLogprobsContentTypedDict",
    "ChatLogprobsTypedDict",
    "ChatUsage",
    "ChatUsageTypedDict",
    "CompleteUploadRequest",
    "CompleteUploadRequestTypedDict",
    "CompletionsBodyWithPrompt",
    "CompletionsBodyWithPromptSeed",
    "CompletionsBodyWithPromptSeedTypedDict",
    "CompletionsBodyWithPromptTypedDict",
    "CompletionsBodyWithTokens",
    "CompletionsBodyWithTokensSeed",
    "CompletionsBodyWithTokensSeedTypedDict",
    "CompletionsBodyWithTokensTypedDict",
    "CompletionsChoice",
    "CompletionsChoiceFinishReason",
    "CompletionsChoiceTypedDict",
    "CompletionsDedicatedBodyWithPrompt",
    "CompletionsDedicatedBodyWithPromptPrompt",
    "CompletionsDedicatedBodyWithPromptPromptTypedDict",
    "CompletionsDedicatedBodyWithPromptSeed",
    "CompletionsDedicatedBodyWithPromptSeedTypedDict",
    "CompletionsDedicatedBodyWithPromptTypedDict",
    "CompletionsDedicatedBodyWithTokens",
    "CompletionsDedicatedBodyWithTokensSeed",
    "CompletionsDedicatedBodyWithTokensSeedTypedDict",
    "CompletionsDedicatedBodyWithTokensTypedDict",
    "CompletionsLogprobs",
    "CompletionsLogprobsTypedDict",
    "CompletionsServerlessBodyWithPrompt",
    "CompletionsServerlessBodyWithPromptPrompt",
    "CompletionsServerlessBodyWithPromptPromptTypedDict",
    "CompletionsServerlessBodyWithPromptSeed",
    "CompletionsServerlessBodyWithPromptSeedTypedDict",
    "CompletionsServerlessBodyWithPromptTypedDict",
    "CompletionsServerlessBodyWithTokens",
    "CompletionsServerlessBodyWithTokensSeed",
    "CompletionsServerlessBodyWithTokensSeedTypedDict",
    "CompletionsServerlessBodyWithTokensTypedDict",
    "CompletionsStreamBodyWithPrompt",
    "CompletionsStreamBodyWithPromptPrompt",
    "CompletionsStreamBodyWithPromptPromptTypedDict",
    "CompletionsStreamBodyWithPromptSeed",
    "CompletionsStreamBodyWithPromptSeedTypedDict",
    "CompletionsStreamBodyWithPromptTypedDict",
    "CompletionsStreamBodyWithTokens",
    "CompletionsStreamBodyWithTokensSeed",
    "CompletionsStreamBodyWithTokensSeedTypedDict",
    "CompletionsStreamBodyWithTokensTypedDict",
    "CompletionsStreamDedicatedBodyWithPrompt",
    "CompletionsStreamDedicatedBodyWithPromptPrompt",
    "CompletionsStreamDedicatedBodyWithPromptPromptTypedDict",
    "CompletionsStreamDedicatedBodyWithPromptSeed",
    "CompletionsStreamDedicatedBodyWithPromptSeedTypedDict",
    "CompletionsStreamDedicatedBodyWithPromptTypedDict",
    "CompletionsStreamDedicatedBodyWithTokens",
    "CompletionsStreamDedicatedBodyWithTokensSeed",
    "CompletionsStreamDedicatedBodyWithTokensSeedTypedDict",
    "CompletionsStreamDedicatedBodyWithTokensTypedDict",
    "CompletionsStreamServerlessBodyWithPrompt",
    "CompletionsStreamServerlessBodyWithPromptPrompt",
    "CompletionsStreamServerlessBodyWithPromptPromptTypedDict",
    "CompletionsStreamServerlessBodyWithPromptSeed",
    "CompletionsStreamServerlessBodyWithPromptSeedTypedDict",
    "CompletionsStreamServerlessBodyWithPromptTypedDict",
    "CompletionsStreamServerlessBodyWithTokens",
    "CompletionsStreamServerlessBodyWithTokensSeed",
    "CompletionsStreamServerlessBodyWithTokensSeedTypedDict",
    "CompletionsStreamServerlessBodyWithTokensTypedDict",
    "ContainerChatCompleteSuccess",
    "ContainerChatCompleteSuccessTypedDict",
    "ContainerChatCompletionBody",
    "ContainerChatCompletionBodyTypedDict",
    "ContainerChatCompletionStreamBody",
    "ContainerChatCompletionStreamBodySeed",
    "ContainerChatCompletionStreamBodySeedTypedDict",
    "ContainerChatCompletionStreamBodyToolChoice",
    "ContainerChatCompletionStreamBodyToolChoiceTypedDict",
    "ContainerChatCompletionStreamBodyTypedDict",
    "ContainerChatCompletionStreamSuccess",
    "ContainerChatCompletionStreamSuccessTypedDict",
    "ContainerCompletionsBody",
    "ContainerCompletionsBodyTypedDict",
    "ContainerCompletionsStreamBody",
    "ContainerCompletionsStreamBodyTypedDict",
    "ContainerCompletionsStreamSuccess",
    "ContainerCompletionsStreamSuccessTypedDict",
    "ContainerCompletionsSuccess",
    "ContainerCompletionsSuccessTypedDict",
    "ContainerDetokenizationBody",
    "ContainerDetokenizationBodyTypedDict",
    "ContainerDetokenizationSuccess",
    "ContainerDetokenizationSuccessTypedDict",
    "ContainerImageGenerateSuccess",
    "ContainerImageGenerateSuccessTypedDict",
    "ContainerImageGenerationBody",
    "ContainerImageGenerationBodyResponseFormat",
    "ContainerImageGenerationBodyTypedDict",
    "ContainerTokenizationBody",
    "ContainerTokenizationBodyTypedDict",
    "ContainerTokenizationSuccess",
    "ContainerTokenizationSuccessTypedDict",
    "Content",
    "ContentTypedDict",
    "CreateDatasetRequest",
    "CreateDatasetRequest1",
    "CreateDatasetRequest1TypedDict",
    "CreateDatasetRequestTypedDict",
    "CreateSplitRequest",
    "CreateSplitRequestTypedDict",
    "CreateVersionRequest",
    "CreateVersionRequestTypedDict",
    "Data",
    "DataTypedDict",
    "DatasetInfo",
    "DatasetInfoTypedDict",
    "DedicatedChatCompleteRequest",
    "DedicatedChatCompleteRequestTypedDict",
    "DedicatedChatCompletionBody",
    "DedicatedChatCompletionBodySeed",
    "DedicatedChatCompletionBodySeedTypedDict",
    "DedicatedChatCompletionBodyToolChoice",
    "DedicatedChatCompletionBodyToolChoiceTypedDict",
    "DedicatedChatCompletionBodyTypedDict",
    "DedicatedChatCompletionStreamBody",
    "DedicatedChatCompletionStreamBodySeed",
    "DedicatedChatCompletionStreamBodySeedTypedDict",
    "DedicatedChatCompletionStreamBodyToolChoice",
    "DedicatedChatCompletionStreamBodyToolChoiceTypedDict",
    "DedicatedChatCompletionStreamBodyTypedDict",
    "DedicatedChatStreamRequest",
    "DedicatedChatStreamRequestTypedDict",
    "DedicatedCompletionsBody",
    "DedicatedCompletionsBodyTypedDict",
    "DedicatedCompletionsCompleteRequest",
    "DedicatedCompletionsCompleteRequestTypedDict",
    "DedicatedCompletionsStreamBody",
    "DedicatedCompletionsStreamBodyTypedDict",
    "DedicatedCompletionsStreamRequest",
    "DedicatedCompletionsStreamRequestTypedDict",
    "DedicatedCreateEndpointBetaRequest",
    "DedicatedCreateEndpointBetaRequestTypedDict",
    "DedicatedCreateEndpointRequest",
    "DedicatedCreateEndpointRequestTypedDict",
    "DedicatedDatasetModality",
    "DedicatedDatasetModalityType",
    "DedicatedDatasetModalityTypedDict",
    "DedicatedDeleteEndpointRequest",
    "DedicatedDeleteEndpointRequestTypedDict",
    "DedicatedDetokenizationBody",
    "DedicatedDetokenizationBodyTypedDict",
    "DedicatedDetokenizationRequest",
    "DedicatedDetokenizationRequestTypedDict",
    "DedicatedDetokenizationSuccess",
    "DedicatedDetokenizationSuccessTypedDict",
    "DedicatedEndpointCreateBody",
    "DedicatedEndpointCreateBodyTypedDict",
    "DedicatedEndpointListResponse",
    "DedicatedEndpointListResponseTypedDict",
    "DedicatedEndpointSpec",
    "DedicatedEndpointSpecBeta",
    "DedicatedEndpointSpecBetaTypedDict",
    "DedicatedEndpointSpecTypedDict",
    "DedicatedEndpointStatus",
    "DedicatedEndpointStatusTypedDict",
    "DedicatedEndpointUpdateBody",
    "DedicatedEndpointUpdateBodyTypedDict",
    "DedicatedEndpointVersionHistoryResponse",
    "DedicatedEndpointVersionHistoryResponseTypedDict",
    "DedicatedEndpointWandbArtifactCreateBody",
    "DedicatedEndpointWandbArtifactCreateBodyTypedDict",
    "DedicatedEndpointWandbArtifactCreateRequest",
    "DedicatedEndpointWandbArtifactCreateRequestTypedDict",
    "DedicatedEndpointWandbArtifactCreateResponse",
    "DedicatedEndpointWandbArtifactCreateResponseTypedDict",
    "DedicatedGetEndpointBetaRequest",
    "DedicatedGetEndpointBetaRequestTypedDict",
    "DedicatedGetEndpointRequest",
    "DedicatedGetEndpointRequestTypedDict",
    "DedicatedGetEndpointStatusBetaRequest",
    "DedicatedGetEndpointStatusBetaRequestTypedDict",
    "DedicatedGetEndpointStatusRequest",
    "DedicatedGetEndpointStatusRequestTypedDict",
    "DedicatedGetEndpointVersionHistoryRequest",
    "DedicatedGetEndpointVersionHistoryRequestTypedDict",
    "DedicatedImageGenerateSuccess",
    "DedicatedImageGenerateSuccessTypedDict",
    "DedicatedImageGenerationBody",
    "DedicatedImageGenerationBodyResponseFormat",
    "DedicatedImageGenerationBodyTypedDict",
    "DedicatedImagesGenerateRequest",
    "DedicatedImagesGenerateRequestTypedDict",
    "DedicatedListEndpointsBetaRequest",
    "DedicatedListEndpointsBetaRequestTypedDict",
    "DedicatedListEndpointsRequest",
    "DedicatedListEndpointsRequestTypedDict",
    "DedicatedRestartEndpointBetaRequest",
    "DedicatedRestartEndpointBetaRequestTypedDict",
    "DedicatedRestartEndpointRequest",
    "DedicatedRestartEndpointRequestTypedDict",
    "DedicatedSleepEndpointRequest",
    "DedicatedSleepEndpointRequestTypedDict",
    "DedicatedTerminateEndpointBetaRequest",
    "DedicatedTerminateEndpointBetaRequestTypedDict",
    "DedicatedTerminateEndpointRequest",
    "DedicatedTerminateEndpointRequestTypedDict",
    "DedicatedTokenizationBody",
    "DedicatedTokenizationBodyTypedDict",
    "DedicatedTokenizationRequest",
    "DedicatedTokenizationRequestTypedDict",
    "DedicatedTokenizationSuccess",
    "DedicatedTokenizationSuccessTypedDict",
    "DedicatedUpdateEndpointBetaRequest",
    "DedicatedUpdateEndpointBetaRequestTypedDict",
    "DedicatedUpdateEndpointRequest",
    "DedicatedUpdateEndpointRequestTypedDict",
    "DedicatedWakeEndpointRequest",
    "DedicatedWakeEndpointRequestTypedDict",
    "DeleteDatasetRequest",
    "DeleteDatasetRequestTypedDict",
    "DeleteSamplesRequest",
    "DeleteSamplesRequestTypedDict",
    "DeleteSamplesResponse",
    "DeleteSamplesResponseTypedDict",
    "DeleteSplitRequest",
    "DeleteSplitRequestTypedDict",
    "DeleteVersionRequest",
    "DeleteVersionRequestTypedDict",
    "Direction",
    "EndpointAdvancedConfig",
    "EndpointAdvancedConfigTypedDict",
    "EndpointSimplescaleConfig",
    "EndpointSimplescaleConfigTypedDict",
    "FileBuiltInTool",
    "FileBuiltInToolTypedDict",
    "FileGetDownloadURLResponse",
    "FileGetDownloadURLResponseTypedDict",
    "FileInfo",
    "FileInfoTypedDict",
    "FileInitUploadRequest",
    "FileInitUploadRequestTypedDict",
    "FileInitUploadResponse",
    "FileInitUploadResponseTypedDict",
    "FileModel",
    "FileModelTypedDict",
    "FinishReason",
    "Function",
    "FunctionResult",
    "FunctionResultTypedDict",
    "FunctionTypedDict",
    "Functionality",
    "FunctionalityTypedDict",
    "GetDatasetRequest",
    "GetDatasetRequestTypedDict",
    "GetDownloadURLRequest",
    "GetDownloadURLRequestTypedDict",
    "GetInfoRequest",
    "GetInfoRequestTypedDict",
    "GetSplitRequest",
    "GetSplitRequestTypedDict",
    "GetVersionRequest",
    "GetVersionRequestTypedDict",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "ImageContent",
    "ImageContentTypedDict",
    "ImageData",
    "ImageDataTypedDict",
    "InferenceDeploymentErrorCode",
    "InferenceDeploymentStatus",
    "InitUploadRequest",
    "InitUploadRequestTypedDict",
    "KnowledgeRetrievedChunk",
    "KnowledgeRetrievedChunkTypedDict",
    "ListDatasetsRequest",
    "ListDatasetsRequestTypedDict",
    "ListDatasetsResponse",
    "ListDatasetsResponseTypedDict",
    "ListSamplesQueryParamDirection",
    "ListSamplesRequest",
    "ListSamplesRequestTypedDict",
    "ListSamplesResponse",
    "ListSamplesResponseTypedDict",
    "ListSplitsRequest",
    "ListSplitsRequestTypedDict",
    "ListSplitsResponse",
    "ListSplitsResponseTypedDict",
    "ListVersionsRequest",
    "ListVersionsRequestTypedDict",
    "ListVersionsResponse",
    "ListVersionsResponseTypedDict",
    "Loc",
    "LocTypedDict",
    "Message",
    "MessageTypedDict",
    "ModelCatalogResponseItem",
    "ModelCatalogResponseItemTypedDict",
    "Name",
    "OtherBuiltInTool",
    "OtherBuiltInToolTypedDict",
    "Phase",
    "PricingModel",
    "PricingModelTypedDict",
    "Prompt",
    "PromptTypedDict",
    "QueryParamDirection",
    "RequestBody",
    "RequestBodyTypedDict",
    "ResponseFormat",
    "ResponseFormatJSONObject",
    "ResponseFormatJSONObjectTypedDict",
    "ResponseFormatJSONSchema",
    "ResponseFormatJSONSchemaSchema",
    "ResponseFormatJSONSchemaSchemaTypedDict",
    "ResponseFormatJSONSchemaTypedDict",
    "ResponseFormatRegex",
    "ResponseFormatRegexTypedDict",
    "ResponseFormatText",
    "ResponseFormatTextTypedDict",
    "ResponseFormatTypedDict",
    "SDKError",
    "Security",
    "SecurityTypedDict",
    "Seed",
    "SeedTypedDict",
    "ServerlessChatCompleteRequest",
    "ServerlessChatCompleteRequestTypedDict",
    "ServerlessChatCompletionBody",
    "ServerlessChatCompletionBodySeed",
    "ServerlessChatCompletionBodySeedTypedDict",
    "ServerlessChatCompletionBodyToolChoice",
    "ServerlessChatCompletionBodyToolChoiceTypedDict",
    "ServerlessChatCompletionBodyTypedDict",
    "ServerlessChatCompletionStreamBody",
    "ServerlessChatCompletionStreamBodySeed",
    "ServerlessChatCompletionStreamBodySeedTypedDict",
    "ServerlessChatCompletionStreamBodyToolChoice",
    "ServerlessChatCompletionStreamBodyToolChoiceTypedDict",
    "ServerlessChatCompletionStreamBodyTypedDict",
    "ServerlessChatStreamRequest",
    "ServerlessChatStreamRequestTypedDict",
    "ServerlessCompletionsBody",
    "ServerlessCompletionsBodyTypedDict",
    "ServerlessCompletionsCompleteRequest",
    "ServerlessCompletionsCompleteRequestTypedDict",
    "ServerlessCompletionsStreamBody",
    "ServerlessCompletionsStreamBodyTypedDict",
    "ServerlessCompletionsStreamRequest",
    "ServerlessCompletionsStreamRequestTypedDict",
    "ServerlessDetokenizationBody",
    "ServerlessDetokenizationBodyTypedDict",
    "ServerlessDetokenizationRequest",
    "ServerlessDetokenizationRequestTypedDict",
    "ServerlessDetokenizationSuccess",
    "ServerlessDetokenizationSuccessTypedDict",
    "ServerlessKnowledgeRetrievalBody",
    "ServerlessKnowledgeRetrievalBodyTypedDict",
    "ServerlessKnowledgeRetrievalSuccess",
    "ServerlessKnowledgeRetrievalSuccessTypedDict",
    "ServerlessKnowledgeRetrieveRequest",
    "ServerlessKnowledgeRetrieveRequestTypedDict",
    "ServerlessModelListSuccess",
    "ServerlessModelListSuccessTypedDict",
    "ServerlessTokenizationBody",
    "ServerlessTokenizationBodyTypedDict",
    "ServerlessTokenizationRequest",
    "ServerlessTokenizationRequestTypedDict",
    "ServerlessTokenizationSuccess",
    "ServerlessTokenizationSuccessTypedDict",
    "ServerlessToolAssistedChatCompleteRequest",
    "ServerlessToolAssistedChatCompleteRequestTypedDict",
    "ServerlessToolAssistedChatCompletionBody",
    "ServerlessToolAssistedChatCompletionBodySeed",
    "ServerlessToolAssistedChatCompletionBodySeedTypedDict",
    "ServerlessToolAssistedChatCompletionBodyToolChoice",
    "ServerlessToolAssistedChatCompletionBodyToolChoiceTypedDict",
    "ServerlessToolAssistedChatCompletionBodyTypedDict",
    "ServerlessToolAssistedChatCompletionStreamBody",
    "ServerlessToolAssistedChatCompletionStreamBodySeed",
    "ServerlessToolAssistedChatCompletionStreamBodySeedTypedDict",
    "ServerlessToolAssistedChatCompletionStreamBodyToolChoice",
    "ServerlessToolAssistedChatCompletionStreamBodyToolChoiceTypedDict",
    "ServerlessToolAssistedChatCompletionStreamBodyTypedDict",
    "ServerlessToolAssistedChatCompletionStreamSuccess",
    "ServerlessToolAssistedChatCompletionStreamSuccessTypedDict",
    "ServerlessToolAssistedChatStreamRequest",
    "ServerlessToolAssistedChatStreamRequestTypedDict",
    "SplitInfo",
    "SplitInfoTypedDict",
    "Status",
    "StreamOptions",
    "StreamOptionsTypedDict",
    "StreamedChatChoice",
    "StreamedChatChoiceDelta",
    "StreamedChatChoiceDeltaTypedDict",
    "StreamedChatChoiceFinishReason",
    "StreamedChatChoiceTypedDict",
    "StreamedChatData",
    "StreamedChatDataTypedDict",
    "StreamedCompletionData",
    "StreamedCompletionDataTypedDict",
    "StreamedCompletionsChoice",
    "StreamedCompletionsChoiceFinishReason",
    "StreamedCompletionsChoiceTypedDict",
    "StreamedFunctionResult",
    "StreamedFunctionResultTypedDict",
    "StreamedToolAssistedChatToken",
    "StreamedToolAssistedChatTokenTypedDict",
    "StreamedToolAssistedChatToolStatus",
    "StreamedToolAssistedChatToolStatusTypedDict",
    "StreamedToolCallResult",
    "StreamedToolCallResultTypedDict",
    "SystemMessage",
    "SystemMessageTypedDict",
    "TextContent",
    "TextContentTypedDict",
    "TokenSequence",
    "TokenSequenceTypedDict",
    "Tool",
    "ToolAssistedChatTool",
    "ToolAssistedChatToolTypedDict",
    "ToolCallResult",
    "ToolCallResultTypedDict",
    "ToolChoice",
    "ToolChoiceTypedDict",
    "ToolMessage",
    "ToolMessageTypedDict",
    "ToolStatusData",
    "ToolStatusDataTypedDict",
    "ToolStatusError",
    "ToolStatusErrorTypedDict",
    "ToolStatusFile",
    "ToolStatusFileTypedDict",
    "ToolStatusParameter",
    "ToolStatusParameterTypedDict",
    "ToolTypedDict",
    "Type",
    "URLImageItem",
    "URLImageItemResponseFormat",
    "URLImageItemTypedDict",
    "UploadRawSamplesRequest",
    "UploadRawSamplesRequestTypedDict",
    "Usage",
    "UsageTypedDict",
    "UserMessage",
    "UserMessageContentMultiModal",
    "UserMessageContentMultiModalTypedDict",
    "UserMessageTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "VersionInfo",
    "VersionInfoTypedDict",
    "VideoContent",
    "VideoContentTypedDict",
    "VideoData",
    "VideoDataTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AcceleratorRequirement": ".acceleratorrequirement",
    "AcceleratorRequirementTypedDict": ".acceleratorrequirement",
    "AccountFileStatus": ".accountfilestatus",
    "AddSamplesRequest": ".add_samplesop",
    "AddSamplesRequestTypedDict": ".add_samplesop",
    "AddSamplesResponse": ".addsamplesresponse",
    "AddSamplesResponseTypedDict": ".addsamplesresponse",
    "AssistantMessage": ".assistantmessage",
    "AssistantMessageTypedDict": ".assistantmessage",
    "AssistantMessageToolCall": ".assistantmessagetoolcall",
    "AssistantMessageToolCallTypedDict": ".assistantmessagetoolcall",
    "AssistantMessageToolCallFunction": ".assistantmessagetoolcallfunction",
    "AssistantMessageToolCallFunctionTypedDict": ".assistantmessagetoolcallfunction",
    "AudioContent": ".audiocontent",
    "AudioContentTypedDict": ".audiocontent",
    "AudioData": ".audiodata",
    "AudioDataTypedDict": ".audiodata",
    "AutoscalingPolicy": ".autoscalingpolicy",
    "AutoscalingPolicyTypedDict": ".autoscalingpolicy",
    "B64ImageItem": ".b64imageitem",
    "B64ImageItemResponseFormat": ".b64imageitem",
    "B64ImageItemTypedDict": ".b64imageitem",
    "BodyUploadRawSamples": ".body_upload_raw_samples",
    "BodyUploadRawSamplesTypedDict": ".body_upload_raw_samples",
    "FileModel": ".body_upload_raw_samples",
    "FileModelTypedDict": ".body_upload_raw_samples",
    "ChatChoice": ".chatchoice",
    "ChatChoiceTypedDict": ".chatchoice",
    "FinishReason": ".chatchoice",
    "ChatChoiceMessage": ".chatchoicemessage",
    "ChatChoiceMessageTypedDict": ".chatchoicemessage",
    "ChatCompleteBodyToolChoice": ".chatcompletebodytoolchoice",
    "ChatCompleteBodyToolChoiceTypedDict": ".chatcompletebodytoolchoice",
    "ChatCompleteBodyToolChoiceFunction": ".chatcompletebodytoolchoicefunction",
    "ChatCompleteBodyToolChoiceFunctionTypedDict": ".chatcompletebodytoolchoicefunction",
    "ChatLogprobs": ".chatlogprobs",
    "ChatLogprobsTypedDict": ".chatlogprobs",
    "ChatLogprobsContent": ".chatlogprobscontent",
    "ChatLogprobsContentTypedDict": ".chatlogprobscontent",
    "ChatLogprobsContentTopLogprob": ".chatlogprobscontenttoplogprob",
    "ChatLogprobsContentTopLogprobTypedDict": ".chatlogprobscontenttoplogprob",
    "ChatUsage": ".chatusage",
    "ChatUsageTypedDict": ".chatusage",
    "CompleteUploadRequest": ".complete_uploadop",
    "CompleteUploadRequestTypedDict": ".complete_uploadop",
    "CompletionsBodyWithPrompt": ".completionsbodywithprompt",
    "CompletionsBodyWithPromptSeed": ".completionsbodywithprompt",
    "CompletionsBodyWithPromptSeedTypedDict": ".completionsbodywithprompt",
    "CompletionsBodyWithPromptTypedDict": ".completionsbodywithprompt",
    "Prompt": ".completionsbodywithprompt",
    "PromptTypedDict": ".completionsbodywithprompt",
    "CompletionsBodyWithTokens": ".completionsbodywithtokens",
    "CompletionsBodyWithTokensSeed": ".completionsbodywithtokens",
    "CompletionsBodyWithTokensSeedTypedDict": ".completionsbodywithtokens",
    "CompletionsBodyWithTokensTypedDict": ".completionsbodywithtokens",
    "CompletionsChoice": ".completionschoice",
    "CompletionsChoiceFinishReason": ".completionschoice",
    "CompletionsChoiceTypedDict": ".completionschoice",
    "CompletionsDedicatedBodyWithPrompt": ".completionsdedicatedbodywithprompt",
    "CompletionsDedicatedBodyWithPromptPrompt": ".completionsdedicatedbodywithprompt",
    "CompletionsDedicatedBodyWithPromptPromptTypedDict": ".completionsdedicatedbodywithprompt",
    "CompletionsDedicatedBodyWithPromptSeed": ".completionsdedicatedbodywithprompt",
    "CompletionsDedicatedBodyWithPromptSeedTypedDict": ".completionsdedicatedbodywithprompt",
    "CompletionsDedicatedBodyWithPromptTypedDict": ".completionsdedicatedbodywithprompt",
    "CompletionsDedicatedBodyWithTokens": ".completionsdedicatedbodywithtokens",
    "CompletionsDedicatedBodyWithTokensSeed": ".completionsdedicatedbodywithtokens",
    "CompletionsDedicatedBodyWithTokensSeedTypedDict": ".completionsdedicatedbodywithtokens",
    "CompletionsDedicatedBodyWithTokensTypedDict": ".completionsdedicatedbodywithtokens",
    "CompletionsLogprobs": ".completionslogprobs",
    "CompletionsLogprobsTypedDict": ".completionslogprobs",
    "CompletionsServerlessBodyWithPrompt": ".completionsserverlessbodywithprompt",
    "CompletionsServerlessBodyWithPromptPrompt": ".completionsserverlessbodywithprompt",
    "CompletionsServerlessBodyWithPromptPromptTypedDict": ".completionsserverlessbodywithprompt",
    "CompletionsServerlessBodyWithPromptSeed": ".completionsserverlessbodywithprompt",
    "CompletionsServerlessBodyWithPromptSeedTypedDict": ".completionsserverlessbodywithprompt",
    "CompletionsServerlessBodyWithPromptTypedDict": ".completionsserverlessbodywithprompt",
    "CompletionsServerlessBodyWithTokens": ".completionsserverlessbodywithtokens",
    "CompletionsServerlessBodyWithTokensSeed": ".completionsserverlessbodywithtokens",
    "CompletionsServerlessBodyWithTokensSeedTypedDict": ".completionsserverlessbodywithtokens",
    "CompletionsServerlessBodyWithTokensTypedDict": ".completionsserverlessbodywithtokens",
    "CompletionsStreamBodyWithPrompt": ".completionsstreambodywithprompt",
    "CompletionsStreamBodyWithPromptPrompt": ".completionsstreambodywithprompt",
    "CompletionsStreamBodyWithPromptPromptTypedDict": ".completionsstreambodywithprompt",
    "CompletionsStreamBodyWithPromptSeed": ".completionsstreambodywithprompt",
    "CompletionsStreamBodyWithPromptSeedTypedDict": ".completionsstreambodywithprompt",
    "CompletionsStreamBodyWithPromptTypedDict": ".completionsstreambodywithprompt",
    "CompletionsStreamBodyWithTokens": ".completionsstreambodywithtokens",
    "CompletionsStreamBodyWithTokensSeed": ".completionsstreambodywithtokens",
    "CompletionsStreamBodyWithTokensSeedTypedDict": ".completionsstreambodywithtokens",
    "CompletionsStreamBodyWithTokensTypedDict": ".completionsstreambodywithtokens",
    "CompletionsStreamDedicatedBodyWithPrompt": ".completionsstreamdedicatedbodywithprompt",
    "CompletionsStreamDedicatedBodyWithPromptPrompt": ".completionsstreamdedicatedbodywithprompt",
    "CompletionsStreamDedicatedBodyWithPromptPromptTypedDict": ".completionsstreamdedicatedbodywithprompt",
    "CompletionsStreamDedicatedBodyWithPromptSeed": ".completionsstreamdedicatedbodywithprompt",
    "CompletionsStreamDedicatedBodyWithPromptSeedTypedDict": ".completionsstreamdedicatedbodywithprompt",
    "CompletionsStreamDedicatedBodyWithPromptTypedDict": ".completionsstreamdedicatedbodywithprompt",
    "CompletionsStreamDedicatedBodyWithTokens": ".completionsstreamdedicatedbodywithtokens",
    "CompletionsStreamDedicatedBodyWithTokensSeed": ".completionsstreamdedicatedbodywithtokens",
    "CompletionsStreamDedicatedBodyWithTokensSeedTypedDict": ".completionsstreamdedicatedbodywithtokens",
    "CompletionsStreamDedicatedBodyWithTokensTypedDict": ".completionsstreamdedicatedbodywithtokens",
    "CompletionsStreamServerlessBodyWithPrompt": ".completionsstreamserverlessbodywithprompt",
    "CompletionsStreamServerlessBodyWithPromptPrompt": ".completionsstreamserverlessbodywithprompt",
    "CompletionsStreamServerlessBodyWithPromptPromptTypedDict": ".completionsstreamserverlessbodywithprompt",
    "CompletionsStreamServerlessBodyWithPromptSeed": ".completionsstreamserverlessbodywithprompt",
    "CompletionsStreamServerlessBodyWithPromptSeedTypedDict": ".completionsstreamserverlessbodywithprompt",
    "CompletionsStreamServerlessBodyWithPromptTypedDict": ".completionsstreamserverlessbodywithprompt",
    "CompletionsStreamServerlessBodyWithTokens": ".completionsstreamserverlessbodywithtokens",
    "CompletionsStreamServerlessBodyWithTokensSeed": ".completionsstreamserverlessbodywithtokens",
    "CompletionsStreamServerlessBodyWithTokensSeedTypedDict": ".completionsstreamserverlessbodywithtokens",
    "CompletionsStreamServerlessBodyWithTokensTypedDict": ".completionsstreamserverlessbodywithtokens",
    "CONTAINER_CHAT_COMPLETE_OP_SERVERS": ".containerchatcompleteop",
    "ContainerChatCompleteSuccess": ".containerchatcompletesuccess",
    "ContainerChatCompleteSuccessTypedDict": ".containerchatcompletesuccess",
    "ContainerChatCompletionBody": ".containerchatcompletionbody",
    "ContainerChatCompletionBodyTypedDict": ".containerchatcompletionbody",
    "Seed": ".containerchatcompletionbody",
    "SeedTypedDict": ".containerchatcompletionbody",
    "ToolChoice": ".containerchatcompletionbody",
    "ToolChoiceTypedDict": ".containerchatcompletionbody",
    "ContainerChatCompletionStreamBody": ".containerchatcompletionstreambody",
    "ContainerChatCompletionStreamBodySeed": ".containerchatcompletionstreambody",
    "ContainerChatCompletionStreamBodySeedTypedDict": ".containerchatcompletionstreambody",
    "ContainerChatCompletionStreamBodyToolChoice": ".containerchatcompletionstreambody",
    "ContainerChatCompletionStreamBodyToolChoiceTypedDict": ".containerchatcompletionstreambody",
    "ContainerChatCompletionStreamBodyTypedDict": ".containerchatcompletionstreambody",
    "ContainerChatCompletionStreamSuccess": ".containerchatcompletionstreamsuccess",
    "ContainerChatCompletionStreamSuccessTypedDict": ".containerchatcompletionstreamsuccess",
    "CONTAINER_CHAT_STREAM_OP_SERVERS": ".containerchatstreamop",
    "ContainerCompletionsBody": ".containercompletionsbody",
    "ContainerCompletionsBodyTypedDict": ".containercompletionsbody",
    "CONTAINER_COMPLETIONS_COMPLETE_OP_SERVERS": ".containercompletionscompleteop",
    "ContainerCompletionsStreamBody": ".containercompletionsstreambody",
    "ContainerCompletionsStreamBodyTypedDict": ".containercompletionsstreambody",
    "CONTAINER_COMPLETIONS_STREAM_OP_SERVERS": ".containercompletionsstreamop",
    "ContainerCompletionsStreamSuccess": ".containercompletionsstreamsuccess",
    "ContainerCompletionsStreamSuccessTypedDict": ".containercompletionsstreamsuccess",
    "ContainerCompletionsSuccess": ".containercompletionssuccess",
    "ContainerCompletionsSuccessTypedDict": ".containercompletionssuccess",
    "ContainerDetokenizationBody": ".containerdetokenizationbody",
    "ContainerDetokenizationBodyTypedDict": ".containerdetokenizationbody",
    "CONTAINER_DETOKENIZATION_OP_SERVERS": ".containerdetokenizationop",
    "ContainerDetokenizationSuccess": ".containerdetokenizationsuccess",
    "ContainerDetokenizationSuccessTypedDict": ".containerdetokenizationsuccess",
    "ContainerImageGenerateSuccess": ".containerimagegeneratesuccess",
    "ContainerImageGenerateSuccessTypedDict": ".containerimagegeneratesuccess",
    "ContainerImageGenerationBody": ".containerimagegenerationbody",
    "ContainerImageGenerationBodyResponseFormat": ".containerimagegenerationbody",
    "ContainerImageGenerationBodyTypedDict": ".containerimagegenerationbody",
    "CONTAINER_IMAGES_GENERATE_OP_SERVERS": ".containerimagesgenerateop",
    "ContainerTokenizationBody": ".containertokenizationbody",
    "ContainerTokenizationBodyTypedDict": ".containertokenizationbody",
    "CONTAINER_TOKENIZATION_OP_SERVERS": ".containertokenizationop",
    "ContainerTokenizationSuccess": ".containertokenizationsuccess",
    "ContainerTokenizationSuccessTypedDict": ".containertokenizationsuccess",
    "CreateDatasetRequest1": ".create_datasetop",
    "CreateDatasetRequest1TypedDict": ".create_datasetop",
    "CreateSplitRequest": ".create_splitop",
    "CreateSplitRequestTypedDict": ".create_splitop",
    "CreateVersionRequest": ".create_versionop",
    "CreateVersionRequestTypedDict": ".create_versionop",
    "CreateDatasetRequest": ".createdatasetrequest",
    "CreateDatasetRequestTypedDict": ".createdatasetrequest",
    "DatasetInfo": ".datasetinfo",
    "DatasetInfoTypedDict": ".datasetinfo",
    "DedicatedChatCompleteRequest": ".dedicatedchatcompleteop",
    "DedicatedChatCompleteRequestTypedDict": ".dedicatedchatcompleteop",
    "DedicatedChatCompletionBody": ".dedicatedchatcompletionbody",
    "DedicatedChatCompletionBodySeed": ".dedicatedchatcompletionbody",
    "DedicatedChatCompletionBodySeedTypedDict": ".dedicatedchatcompletionbody",
    "DedicatedChatCompletionBodyToolChoice": ".dedicatedchatcompletionbody",
    "DedicatedChatCompletionBodyToolChoiceTypedDict": ".dedicatedchatcompletionbody",
    "DedicatedChatCompletionBodyTypedDict": ".dedicatedchatcompletionbody",
    "DedicatedChatCompletionStreamBody": ".dedicatedchatcompletionstreambody",
    "DedicatedChatCompletionStreamBodySeed": ".dedicatedchatcompletionstreambody",
    "DedicatedChatCompletionStreamBodySeedTypedDict": ".dedicatedchatcompletionstreambody",
    "DedicatedChatCompletionStreamBodyToolChoice": ".dedicatedchatcompletionstreambody",
    "DedicatedChatCompletionStreamBodyToolChoiceTypedDict": ".dedicatedchatcompletionstreambody",
    "DedicatedChatCompletionStreamBodyTypedDict": ".dedicatedchatcompletionstreambody",
    "DedicatedChatStreamRequest": ".dedicatedchatstreamop",
    "DedicatedChatStreamRequestTypedDict": ".dedicatedchatstreamop",
    "DedicatedCompletionsBody": ".dedicatedcompletionsbody",
    "DedicatedCompletionsBodyTypedDict": ".dedicatedcompletionsbody",
    "DedicatedCompletionsCompleteRequest": ".dedicatedcompletionscompleteop",
    "DedicatedCompletionsCompleteRequestTypedDict": ".dedicatedcompletionscompleteop",
    "DedicatedCompletionsStreamBody": ".dedicatedcompletionsstreambody",
    "DedicatedCompletionsStreamBodyTypedDict": ".dedicatedcompletionsstreambody",
    "DedicatedCompletionsStreamRequest": ".dedicatedcompletionsstreamop",
    "DedicatedCompletionsStreamRequestTypedDict": ".dedicatedcompletionsstreamop",
    "DedicatedCreateEndpointBetaRequest": ".dedicatedcreateendpointbetaop",
    "DedicatedCreateEndpointBetaRequestTypedDict": ".dedicatedcreateendpointbetaop",
    "DedicatedCreateEndpointRequest": ".dedicatedcreateendpointop",
    "DedicatedCreateEndpointRequestTypedDict": ".dedicatedcreateendpointop",
    "DedicatedDatasetModality": ".dedicateddatasetmodality",
    "DedicatedDatasetModalityTypedDict": ".dedicateddatasetmodality",
    "DedicatedDatasetModalityType": ".dedicateddatasetmodalitytype",
    "DedicatedDeleteEndpointRequest": ".dedicateddeleteendpointop",
    "DedicatedDeleteEndpointRequestTypedDict": ".dedicateddeleteendpointop",
    "DedicatedDetokenizationBody": ".dedicateddetokenizationbody",
    "DedicatedDetokenizationBodyTypedDict": ".dedicateddetokenizationbody",
    "DedicatedDetokenizationRequest": ".dedicateddetokenizationop",
    "DedicatedDetokenizationRequestTypedDict": ".dedicateddetokenizationop",
    "DedicatedDetokenizationSuccess": ".dedicateddetokenizationsuccess",
    "DedicatedDetokenizationSuccessTypedDict": ".dedicateddetokenizationsuccess",
    "DedicatedEndpointCreateBody": ".dedicatedendpointcreatebody",
    "DedicatedEndpointCreateBodyTypedDict": ".dedicatedendpointcreatebody",
    "DedicatedEndpointListResponse": ".dedicatedendpointlistresponse",
    "DedicatedEndpointListResponseTypedDict": ".dedicatedendpointlistresponse",
    "DedicatedEndpointSpec": ".dedicatedendpointspec",
    "DedicatedEndpointSpecTypedDict": ".dedicatedendpointspec",
    "DedicatedEndpointSpecBeta": ".dedicatedendpointspecbeta",
    "DedicatedEndpointSpecBetaTypedDict": ".dedicatedendpointspecbeta",
    "DedicatedEndpointStatus": ".dedicatedendpointstatus",
    "DedicatedEndpointStatusTypedDict": ".dedicatedendpointstatus",
    "Phase": ".dedicatedendpointstatus",
    "DedicatedEndpointUpdateBody": ".dedicatedendpointupdatebody",
    "DedicatedEndpointUpdateBodyTypedDict": ".dedicatedendpointupdatebody",
    "DedicatedEndpointVersionHistoryResponse": ".dedicatedendpointversionhistoryresponse",
    "DedicatedEndpointVersionHistoryResponseTypedDict": ".dedicatedendpointversionhistoryresponse",
    "DedicatedEndpointWandbArtifactCreateBody": ".dedicatedendpointwandbartifactcreatebody",
    "DedicatedEndpointWandbArtifactCreateBodyTypedDict": ".dedicatedendpointwandbartifactcreatebody",
    "DedicatedEndpointWandbArtifactCreateRequest": ".dedicatedendpointwandbartifactcreateop",
    "DedicatedEndpointWandbArtifactCreateRequestTypedDict": ".dedicatedendpointwandbartifactcreateop",
    "DedicatedEndpointWandbArtifactCreateResponse": ".dedicatedendpointwandbartifactcreateresponse",
    "DedicatedEndpointWandbArtifactCreateResponseTypedDict": ".dedicatedendpointwandbartifactcreateresponse",
    "DedicatedGetEndpointBetaRequest": ".dedicatedgetendpointbetaop",
    "DedicatedGetEndpointBetaRequestTypedDict": ".dedicatedgetendpointbetaop",
    "DedicatedGetEndpointRequest": ".dedicatedgetendpointop",
    "DedicatedGetEndpointRequestTypedDict": ".dedicatedgetendpointop",
    "DedicatedGetEndpointStatusBetaRequest": ".dedicatedgetendpointstatusbetaop",
    "DedicatedGetEndpointStatusBetaRequestTypedDict": ".dedicatedgetendpointstatusbetaop",
    "DedicatedGetEndpointStatusRequest": ".dedicatedgetendpointstatusop",
    "DedicatedGetEndpointStatusRequestTypedDict": ".dedicatedgetendpointstatusop",
    "DedicatedGetEndpointVersionHistoryRequest": ".dedicatedgetendpointversionhistoryop",
    "DedicatedGetEndpointVersionHistoryRequestTypedDict": ".dedicatedgetendpointversionhistoryop",
    "Data": ".dedicatedimagegeneratesuccess",
    "DataTypedDict": ".dedicatedimagegeneratesuccess",
    "DedicatedImageGenerateSuccess": ".dedicatedimagegeneratesuccess",
    "DedicatedImageGenerateSuccessTypedDict": ".dedicatedimagegeneratesuccess",
    "DedicatedImageGenerationBody": ".dedicatedimagegenerationbody",
    "DedicatedImageGenerationBodyResponseFormat": ".dedicatedimagegenerationbody",
    "DedicatedImageGenerationBodyTypedDict": ".dedicatedimagegenerationbody",
    "DedicatedImagesGenerateRequest": ".dedicatedimagesgenerateop",
    "DedicatedImagesGenerateRequestTypedDict": ".dedicatedimagesgenerateop",
    "DedicatedListEndpointsBetaRequest": ".dedicatedlistendpointsbetaop",
    "DedicatedListEndpointsBetaRequestTypedDict": ".dedicatedlistendpointsbetaop",
    "DedicatedListEndpointsRequest": ".dedicatedlistendpointsop",
    "DedicatedListEndpointsRequestTypedDict": ".dedicatedlistendpointsop",
    "DedicatedRestartEndpointBetaRequest": ".dedicatedrestartendpointbetaop",
    "DedicatedRestartEndpointBetaRequestTypedDict": ".dedicatedrestartendpointbetaop",
    "DedicatedRestartEndpointRequest": ".dedicatedrestartendpointop",
    "DedicatedRestartEndpointRequestTypedDict": ".dedicatedrestartendpointop",
    "DedicatedSleepEndpointRequest": ".dedicatedsleependpointop",
    "DedicatedSleepEndpointRequestTypedDict": ".dedicatedsleependpointop",
    "DedicatedTerminateEndpointBetaRequest": ".dedicatedterminateendpointbetaop",
    "DedicatedTerminateEndpointBetaRequestTypedDict": ".dedicatedterminateendpointbetaop",
    "DedicatedTerminateEndpointRequest": ".dedicatedterminateendpointop",
    "DedicatedTerminateEndpointRequestTypedDict": ".dedicatedterminateendpointop",
    "DedicatedTokenizationBody": ".dedicatedtokenizationbody",
    "DedicatedTokenizationBodyTypedDict": ".dedicatedtokenizationbody",
    "DedicatedTokenizationRequest": ".dedicatedtokenizationop",
    "DedicatedTokenizationRequestTypedDict": ".dedicatedtokenizationop",
    "DedicatedTokenizationSuccess": ".dedicatedtokenizationsuccess",
    "DedicatedTokenizationSuccessTypedDict": ".dedicatedtokenizationsuccess",
    "DedicatedUpdateEndpointBetaRequest": ".dedicatedupdateendpointbetaop",
    "DedicatedUpdateEndpointBetaRequestTypedDict": ".dedicatedupdateendpointbetaop",
    "DedicatedUpdateEndpointRequest": ".dedicatedupdateendpointop",
    "DedicatedUpdateEndpointRequestTypedDict": ".dedicatedupdateendpointop",
    "DedicatedWakeEndpointRequest": ".dedicatedwakeendpointop",
    "DedicatedWakeEndpointRequestTypedDict": ".dedicatedwakeendpointop",
    "DeleteDatasetRequest": ".delete_datasetop",
    "DeleteDatasetRequestTypedDict": ".delete_datasetop",
    "DeleteSamplesRequest": ".delete_samplesop",
    "DeleteSamplesRequestTypedDict": ".delete_samplesop",
    "RequestBody": ".delete_samplesop",
    "RequestBodyTypedDict": ".delete_samplesop",
    "DeleteSplitRequest": ".delete_splitop",
    "DeleteSplitRequestTypedDict": ".delete_splitop",
    "DeleteVersionRequest": ".delete_versionop",
    "DeleteVersionRequestTypedDict": ".delete_versionop",
    "DeleteSamplesResponse": ".deletesamplesresponse",
    "DeleteSamplesResponseTypedDict": ".deletesamplesresponse",
    "EndpointAdvancedConfig": ".endpointadvancedconfig",
    "EndpointAdvancedConfigTypedDict": ".endpointadvancedconfig",
    "EndpointSimplescaleConfig": ".endpointsimplescaleconfig",
    "EndpointSimplescaleConfigTypedDict": ".endpointsimplescaleconfig",
    "FileBuiltInTool": ".filebuiltintool",
    "FileBuiltInToolTypedDict": ".filebuiltintool",
    "FileGetDownloadURLResponse": ".filegetdownloadurlresponse",
    "FileGetDownloadURLResponseTypedDict": ".filegetdownloadurlresponse",
    "FileInfo": ".fileinfo",
    "FileInfoTypedDict": ".fileinfo",
    "FileInitUploadRequest": ".fileinituploadrequest",
    "FileInitUploadRequestTypedDict": ".fileinituploadrequest",
    "FileInitUploadResponse": ".fileinituploadresponse",
    "FileInitUploadResponseTypedDict": ".fileinituploadresponse",
    "Function": ".function",
    "FunctionTypedDict": ".function",
    "Functionality": ".functionality",
    "FunctionalityTypedDict": ".functionality",
    "FunctionResult": ".functionresult",
    "FunctionResultTypedDict": ".functionresult",
    "GetDatasetRequest": ".get_datasetop",
    "GetDatasetRequestTypedDict": ".get_datasetop",
    "GetDownloadURLRequest": ".get_download_urlop",
    "GetDownloadURLRequestTypedDict": ".get_download_urlop",
    "GetInfoRequest": ".get_infoop",
    "GetInfoRequestTypedDict": ".get_infoop",
    "GetSplitRequest": ".get_splitop",
    "GetSplitRequestTypedDict": ".get_splitop",
    "GetVersionRequest": ".get_versionop",
    "GetVersionRequestTypedDict": ".get_versionop",
    "HTTPValidationError": ".httpvalidationerror",
    "HTTPValidationErrorData": ".httpvalidationerror",
    "ImageContent": ".imagecontent",
    "ImageContentTypedDict": ".imagecontent",
    "ImageData": ".imagedata",
    "ImageDataTypedDict": ".imagedata",
    "InferenceDeploymentErrorCode": ".inferencedeploymenterrorcode",
    "InferenceDeploymentStatus": ".inferencedeploymentstatus",
    "InitUploadRequest": ".init_uploadop",
    "InitUploadRequestTypedDict": ".init_uploadop",
    "KnowledgeRetrievedChunk": ".knowledgeretrievedchunk",
    "KnowledgeRetrievedChunkTypedDict": ".knowledgeretrievedchunk",
    "Direction": ".list_datasetsop",
    "ListDatasetsRequest": ".list_datasetsop",
    "ListDatasetsRequestTypedDict": ".list_datasetsop",
    "ListSamplesQueryParamDirection": ".list_samplesop",
    "ListSamplesRequest": ".list_samplesop",
    "ListSamplesRequestTypedDict": ".list_samplesop",
    "ListSplitsRequest": ".list_splitsop",
    "ListSplitsRequestTypedDict": ".list_splitsop",
    "QueryParamDirection": ".list_splitsop",
    "ListVersionsRequest": ".list_versionsop",
    "ListVersionsRequestTypedDict": ".list_versionsop",
    "ListDatasetsResponse": ".listdatasetsresponse",
    "ListDatasetsResponseTypedDict": ".listdatasetsresponse",
    "ListSamplesResponse": ".listsamplesresponse",
    "ListSamplesResponseTypedDict": ".listsamplesresponse",
    "ListSplitsResponse": ".listsplitsresponse",
    "ListSplitsResponseTypedDict": ".listsplitsresponse",
    "ListVersionsResponse": ".listversionsresponse",
    "ListVersionsResponseTypedDict": ".listversionsresponse",
    "Message": ".message",
    "MessageTypedDict": ".message",
    "ModelCatalogResponseItem": ".modelcatalogresponseitem",
    "ModelCatalogResponseItemTypedDict": ".modelcatalogresponseitem",
    "OtherBuiltInTool": ".otherbuiltintool",
    "OtherBuiltInToolTypedDict": ".otherbuiltintool",
    "Type": ".otherbuiltintool",
    "PricingModel": ".pricingmodel",
    "PricingModelTypedDict": ".pricingmodel",
    "ResponseFormat": ".responseformat",
    "ResponseFormatTypedDict": ".responseformat",
    "ResponseFormatJSONObject": ".responseformatjsonobject",
    "ResponseFormatJSONObjectTypedDict": ".responseformatjsonobject",
    "ResponseFormatJSONSchema": ".responseformatjsonschema",
    "ResponseFormatJSONSchemaTypedDict": ".responseformatjsonschema",
    "ResponseFormatJSONSchemaSchema": ".responseformatjsonschemaschema",
    "ResponseFormatJSONSchemaSchemaTypedDict": ".responseformatjsonschemaschema",
    "ResponseFormatRegex": ".responseformatregex",
    "ResponseFormatRegexTypedDict": ".responseformatregex",
    "ResponseFormatText": ".responseformattext",
    "ResponseFormatTextTypedDict": ".responseformattext",
    "SDKError": ".sdkerror",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "ServerlessChatCompleteRequest": ".serverlesschatcompleteop",
    "ServerlessChatCompleteRequestTypedDict": ".serverlesschatcompleteop",
    "ServerlessChatCompletionBody": ".serverlesschatcompletionbody",
    "ServerlessChatCompletionBodySeed": ".serverlesschatcompletionbody",
    "ServerlessChatCompletionBodySeedTypedDict": ".serverlesschatcompletionbody",
    "ServerlessChatCompletionBodyToolChoice": ".serverlesschatcompletionbody",
    "ServerlessChatCompletionBodyToolChoiceTypedDict": ".serverlesschatcompletionbody",
    "ServerlessChatCompletionBodyTypedDict": ".serverlesschatcompletionbody",
    "ServerlessChatCompletionStreamBody": ".serverlesschatcompletionstreambody",
    "ServerlessChatCompletionStreamBodySeed": ".serverlesschatcompletionstreambody",
    "ServerlessChatCompletionStreamBodySeedTypedDict": ".serverlesschatcompletionstreambody",
    "ServerlessChatCompletionStreamBodyToolChoice": ".serverlesschatcompletionstreambody",
    "ServerlessChatCompletionStreamBodyToolChoiceTypedDict": ".serverlesschatcompletionstreambody",
    "ServerlessChatCompletionStreamBodyTypedDict": ".serverlesschatcompletionstreambody",
    "ServerlessChatStreamRequest": ".serverlesschatstreamop",
    "ServerlessChatStreamRequestTypedDict": ".serverlesschatstreamop",
    "ServerlessCompletionsBody": ".serverlesscompletionsbody",
    "ServerlessCompletionsBodyTypedDict": ".serverlesscompletionsbody",
    "ServerlessCompletionsCompleteRequest": ".serverlesscompletionscompleteop",
    "ServerlessCompletionsCompleteRequestTypedDict": ".serverlesscompletionscompleteop",
    "ServerlessCompletionsStreamBody": ".serverlesscompletionsstreambody",
    "ServerlessCompletionsStreamBodyTypedDict": ".serverlesscompletionsstreambody",
    "ServerlessCompletionsStreamRequest": ".serverlesscompletionsstreamop",
    "ServerlessCompletionsStreamRequestTypedDict": ".serverlesscompletionsstreamop",
    "ServerlessDetokenizationBody": ".serverlessdetokenizationbody",
    "ServerlessDetokenizationBodyTypedDict": ".serverlessdetokenizationbody",
    "ServerlessDetokenizationRequest": ".serverlessdetokenizationop",
    "ServerlessDetokenizationRequestTypedDict": ".serverlessdetokenizationop",
    "ServerlessDetokenizationSuccess": ".serverlessdetokenizationsuccess",
    "ServerlessDetokenizationSuccessTypedDict": ".serverlessdetokenizationsuccess",
    "ServerlessKnowledgeRetrievalBody": ".serverlessknowledgeretrievalbody",
    "ServerlessKnowledgeRetrievalBodyTypedDict": ".serverlessknowledgeretrievalbody",
    "ServerlessKnowledgeRetrievalSuccess": ".serverlessknowledgeretrievalsuccess",
    "ServerlessKnowledgeRetrievalSuccessTypedDict": ".serverlessknowledgeretrievalsuccess",
    "ServerlessKnowledgeRetrieveRequest": ".serverlessknowledgeretrieveop",
    "ServerlessKnowledgeRetrieveRequestTypedDict": ".serverlessknowledgeretrieveop",
    "ServerlessModelListSuccess": ".serverlessmodellistsuccess",
    "ServerlessModelListSuccessTypedDict": ".serverlessmodellistsuccess",
    "ServerlessTokenizationBody": ".serverlesstokenizationbody",
    "ServerlessTokenizationBodyTypedDict": ".serverlesstokenizationbody",
    "ServerlessTokenizationRequest": ".serverlesstokenizationop",
    "ServerlessTokenizationRequestTypedDict": ".serverlesstokenizationop",
    "ServerlessTokenizationSuccess": ".serverlesstokenizationsuccess",
    "ServerlessTokenizationSuccessTypedDict": ".serverlesstokenizationsuccess",
    "ServerlessToolAssistedChatCompleteRequest": ".serverlesstoolassistedchatcompleteop",
    "ServerlessToolAssistedChatCompleteRequestTypedDict": ".serverlesstoolassistedchatcompleteop",
    "ServerlessToolAssistedChatCompletionBody": ".serverlesstoolassistedchatcompletionbody",
    "ServerlessToolAssistedChatCompletionBodySeed": ".serverlesstoolassistedchatcompletionbody",
    "ServerlessToolAssistedChatCompletionBodySeedTypedDict": ".serverlesstoolassistedchatcompletionbody",
    "ServerlessToolAssistedChatCompletionBodyToolChoice": ".serverlesstoolassistedchatcompletionbody",
    "ServerlessToolAssistedChatCompletionBodyToolChoiceTypedDict": ".serverlesstoolassistedchatcompletionbody",
    "ServerlessToolAssistedChatCompletionBodyTypedDict": ".serverlesstoolassistedchatcompletionbody",
    "ServerlessToolAssistedChatCompletionStreamBody": ".serverlesstoolassistedchatcompletionstreambody",
    "ServerlessToolAssistedChatCompletionStreamBodySeed": ".serverlesstoolassistedchatcompletionstreambody",
    "ServerlessToolAssistedChatCompletionStreamBodySeedTypedDict": ".serverlesstoolassistedchatcompletionstreambody",
    "ServerlessToolAssistedChatCompletionStreamBodyToolChoice": ".serverlesstoolassistedchatcompletionstreambody",
    "ServerlessToolAssistedChatCompletionStreamBodyToolChoiceTypedDict": ".serverlesstoolassistedchatcompletionstreambody",
    "ServerlessToolAssistedChatCompletionStreamBodyTypedDict": ".serverlesstoolassistedchatcompletionstreambody",
    "ServerlessToolAssistedChatCompletionStreamSuccess": ".serverlesstoolassistedchatcompletionstreamsuccess",
    "ServerlessToolAssistedChatCompletionStreamSuccessTypedDict": ".serverlesstoolassistedchatcompletionstreamsuccess",
    "ServerlessToolAssistedChatStreamRequest": ".serverlesstoolassistedchatstreamop",
    "ServerlessToolAssistedChatStreamRequestTypedDict": ".serverlesstoolassistedchatstreamop",
    "SplitInfo": ".splitinfo",
    "SplitInfoTypedDict": ".splitinfo",
    "StreamedChatChoice": ".streamedchatchoice",
    "StreamedChatChoiceFinishReason": ".streamedchatchoice",
    "StreamedChatChoiceTypedDict": ".streamedchatchoice",
    "StreamedChatChoiceDelta": ".streamedchatchoicedelta",
    "StreamedChatChoiceDeltaTypedDict": ".streamedchatchoicedelta",
    "StreamedChatData": ".streamedchatdata",
    "StreamedChatDataTypedDict": ".streamedchatdata",
    "StreamedCompletionData": ".streamedcompletiondata",
    "StreamedCompletionDataTypedDict": ".streamedcompletiondata",
    "StreamedCompletionsChoice": ".streamedcompletionschoice",
    "StreamedCompletionsChoiceFinishReason": ".streamedcompletionschoice",
    "StreamedCompletionsChoiceTypedDict": ".streamedcompletionschoice",
    "StreamedFunctionResult": ".streamedfunctionresult",
    "StreamedFunctionResultTypedDict": ".streamedfunctionresult",
    "StreamedToolAssistedChatToken": ".streamedtoolassistedchattoken",
    "StreamedToolAssistedChatTokenTypedDict": ".streamedtoolassistedchattoken",
    "StreamedToolAssistedChatToolStatus": ".streamedtoolassistedchattoolstatus",
    "StreamedToolAssistedChatToolStatusTypedDict": ".streamedtoolassistedchattoolstatus",
    "StreamedToolCallResult": ".streamedtoolcallresult",
    "StreamedToolCallResultTypedDict": ".streamedtoolcallresult",
    "StreamOptions": ".streamoptions",
    "StreamOptionsTypedDict": ".streamoptions",
    "SystemMessage": ".systemmessage",
    "SystemMessageTypedDict": ".systemmessage",
    "TextContent": ".textcontent",
    "TextContentTypedDict": ".textcontent",
    "TokenSequence": ".tokensequence",
    "TokenSequenceTypedDict": ".tokensequence",
    "Tool": ".tool",
    "ToolTypedDict": ".tool",
    "ToolAssistedChatTool": ".toolassistedchattool",
    "ToolAssistedChatToolTypedDict": ".toolassistedchattool",
    "ToolCallResult": ".toolcallresult",
    "ToolCallResultTypedDict": ".toolcallresult",
    "ToolMessage": ".toolmessage",
    "ToolMessageTypedDict": ".toolmessage",
    "Name": ".toolstatusdata",
    "Status": ".toolstatusdata",
    "ToolStatusData": ".toolstatusdata",
    "ToolStatusDataTypedDict": ".toolstatusdata",
    "ToolStatusError": ".toolstatuserror",
    "ToolStatusErrorTypedDict": ".toolstatuserror",
    "ToolStatusFile": ".toolstatusfile",
    "ToolStatusFileTypedDict": ".toolstatusfile",
    "ToolStatusParameter": ".toolstatusparameter",
    "ToolStatusParameterTypedDict": ".toolstatusparameter",
    "UploadRawSamplesRequest": ".upload_raw_samplesop",
    "UploadRawSamplesRequestTypedDict": ".upload_raw_samplesop",
    "URLImageItem": ".urlimageitem",
    "URLImageItemResponseFormat": ".urlimageitem",
    "URLImageItemTypedDict": ".urlimageitem",
    "Usage": ".usage",
    "UsageTypedDict": ".usage",
    "Content": ".usermessage",
    "ContentTypedDict": ".usermessage",
    "UserMessage": ".usermessage",
    "UserMessageTypedDict": ".usermessage",
    "UserMessageContentMultiModal": ".usermessagecontentmultimodal",
    "UserMessageContentMultiModalTypedDict": ".usermessagecontentmultimodal",
    "Loc": ".validationerror",
    "LocTypedDict": ".validationerror",
    "ValidationError": ".validationerror",
    "ValidationErrorTypedDict": ".validationerror",
    "VersionInfo": ".versioninfo",
    "VersionInfoTypedDict": ".versioninfo",
    "VideoContent": ".videocontent",
    "VideoContentTypedDict": ".videocontent",
    "VideoData": ".videodata",
    "VideoDataTypedDict": ".videodata",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)
