"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import List

from typing_extensions import TypedDict

from friendli_core.types import BaseModel

from .versioninfo import VersionInfo, VersionInfoTypedDict


class ListVersionsResponseTypedDict(TypedDict):
    r"""List versions response."""

    versions: List[VersionInfoTypedDict]
    r"""List of versions."""


class ListVersionsResponse(BaseModel):
    r"""List versions response."""

    versions: List[VersionInfo]
    r"""List of versions."""
