"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

AccountFileStatus = Literal["UPLOADING", "UPLOADED", "FAILED", "DELETED"]
r"""AccountFile status."""
