"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

import pydantic
from typing_extensions import Annotated, TypedDict

from friendli_core.types import BaseModel

from .dedicateddatasetmodality import (
    DedicatedDatasetModality,
    DedicatedDatasetModalityTypedDict,
)


class CreateDatasetRequestTypedDict(TypedDict):
    r"""Create dataset request."""

    modality: DedicatedDatasetModalityTypedDict
    r"""Dataset modality."""
    name: str
    r"""Name of the dataset."""
    project_id: str
    r"""ID of the project."""


class CreateDatasetRequest(BaseModel):
    r"""Create dataset request."""

    modality: DedicatedDatasetModality
    r"""Dataset modality."""

    name: str
    r"""Name of the dataset."""

    project_id: Annotated[str, pydantic.Field(alias="projectId")]
    r"""ID of the project."""
